import { __rest, __assign } from './../external/tslib/tslib.es6.js';
import React, { useState, useRef, useCallback } from 'react';
import classnames from 'classnames';
import { parseMetadata, forkHandlers } from '@highlight-ui/utils-commons';
import { useAutoPositioner, useForkRef } from '@highlight-ui/utils-hooks';
import { useLocale } from '@highlight-ui/i18n';
import format from './../external/date-fns/esm/format/index.js';
import { getDateConfigByLocale } from './private/date-time-config.js';
import Calendar from './private/Calendar.js';
import DateInput from './private/DateInput.js';
import styles from './RangeDatePicker.module.scss.js';

var RangeDatePicker = function (_a) {
  var className = _a.className,
      range = _a.range,
      onChange = _a.onChange,
      minDate = _a.minDate,
      maxDate = _a.maxDate,
      disabledDates = _a.disabledDates,
      _b = _a.disabled,
      disabled = _b === void 0 ? false : _b,
      _c = _a.closeOnSelect,
      closeOnSelect = _c === void 0 ? true : _c,
      metadata = _a.metadata,
      startInputId = _a.startInputId,
      endInputId = _a.endInputId,
      onFocus = _a.onFocus,
      onBlur = _a.onBlur,
      onClick = _a.onClick,
      restProps = __rest(_a, ["className", "range", "onChange", "minDate", "maxDate", "disabledDates", "disabled", "closeOnSelect", "metadata", "startInputId", "endInputId", "onFocus", "onBlur", "onClick"]);
  /** This block is only needed to keep track of the (intermediate) values from inputs
   * If we stop providing those "broken" values (like "1_/12/2021") via `onChange`,
   * we don't need them here.
   */


  var locale = useLocale().locale;
  var parseFormat = getDateConfigByLocale(locale)({
    minDate: minDate,
    maxDate: maxDate,
    disabledDates: disabledDates
  }).parseFormat;

  var _d = useState([range && range[0] ? format(range[0], parseFormat) : '', range && range[1] ? format(range[1], parseFormat) : '']),
      strRange = _d[0],
      setStrRange = _d[1];
  /** end of the block */


  var rangeStartInput = useRef(null);
  var rangeEndInput = useRef(null);

  var _e = useState(false),
      isOpened = _e[0],
      setIsOpened = _e[1];

  var _f = useAutoPositioner(),
      setReferenceElement = _f.setReferenceElement,
      setPopperElement = _f.setPopperElement,
      popperStyles = _f.styles.popper,
      attributes = _f.attributes;

  var onCalendarChange = useCallback(function (dates, datesAsStrings) {
    if (dates.length === 2 && onChange) {
      var newRange = dates;
      var newRangeAsStrings = datesAsStrings.split(' to ');
      setStrRange(newRangeAsStrings);
      onChange(newRange, newRangeAsStrings);
      if (closeOnSelect) setIsOpened(false);
    }
  }, [closeOnSelect, onChange]);
  var onStartDateChange = useCallback(function (startDate, strStartRange) {
    if (onChange) {
      var endDate = range === null || range === void 0 ? void 0 : range[1];
      var newRange = [startDate, endDate];
      setStrRange(function (oldStrRange) {
        return [strStartRange, oldStrRange[1]];
      });
      onChange(newRange, [strStartRange, strRange[1]]);
    }
  }, [onChange, range, strRange]);
  var onEndDateChange = useCallback(function (endDate, strEndRange) {
    if (onChange) {
      var startDate = range === null || range === void 0 ? void 0 : range[0];
      var newRange = [startDate, endDate];
      setStrRange(function (oldStrRange) {
        return [oldStrRange[0], strEndRange];
      });
      onChange(newRange, [strRange[0], strEndRange]);
    }
  }, [onChange, range, strRange]);
  var rangeStartFinalRef = useForkRef([rangeStartInput, setReferenceElement]);
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", __assign({}, parseMetadata(metadata), {
    className: classnames(styles.rangeDatePickerInputsGroup, className),
    ref: setReferenceElement
  }), /*#__PURE__*/React.createElement(DateInput, __assign({}, restProps, startInputId ? {
    id: startInputId
  } : {}, metadata ? {
    metadata: {
      testId: "dateInput-start-" + metadata.testId
    }
  } : {}, {
    mode: "date",
    disabled: disabled,
    minDate: minDate,
    maxDate: maxDate,
    disabledDates: disabledDates,
    onChange: onStartDateChange,
    onFocus: forkHandlers([function () {
      return setIsOpened(true);
    }, onFocus]),
    onClick: forkHandlers([function () {
      return setIsOpened(true);
    }, onClick]),
    withIcon: true,
    value: range && range[0],
    ref: rangeStartFinalRef,
    className: styles.rangeDatePickerInput
  })), /*#__PURE__*/React.createElement(DateInput, __assign({}, restProps, endInputId ? {
    id: endInputId
  } : {}, metadata ? {
    metadata: {
      testId: "dateInput-end-" + metadata.testId
    }
  } : {}, {
    mode: "date",
    disabled: disabled,
    minDate: minDate,
    maxDate: maxDate,
    disabledDates: disabledDates,
    onChange: onEndDateChange,
    onBlur: onBlur,
    onFocus: forkHandlers([function () {
      return setIsOpened(true);
    }, onFocus]),
    onClick: forkHandlers([function () {
      return setIsOpened(true);
    }, onClick]),
    withIcon: true,
    value: range && range[1],
    ref: function (input) {
      // react-imask requires ref to be a function
      // https://github.com/uNmAnNeR/imaskjs/blob/master/packages/react-imask/src/mixin.js#L63
      rangeEndInput.current = input;
    },
    className: styles.rangeDatePickerInput
  }))), isOpened && /*#__PURE__*/React.createElement(Calendar, __assign({
    isOpened: isOpened,
    minDate: minDate,
    maxDate: maxDate,
    value: range,
    onClickOutside: function (target) {
      var _a, _b;

      if (((_a = rangeStartInput.current) === null || _a === void 0 ? void 0 : _a.contains(target)) || ((_b = rangeEndInput.current) === null || _b === void 0 ? void 0 : _b.contains(target))) {
        return;
      }

      setIsOpened(false);
    },
    disabledDates: disabledDates,
    onChange: onCalendarChange,
    mode: "range",
    metadata: metadata,
    ref: setPopperElement,
    style: popperStyles
  }, attributes.popper)));
};

export { RangeDatePicker as default };
//# sourceMappingURL=RangeDatePicker.js.map
