import { __rest, __assign } from './../../external/tslib/tslib.es6.js';
import React, { useRef, useEffect } from 'react';
import classnames from 'classnames';
import flatpickr from './../../external/flatpickr/dist/esm/index.js';
import { useLocale } from '@highlight-ui/i18n';
import { parseMetadata } from '@highlight-ui/utils-commons';
import { useClickOutside } from '@highlight-ui/utils-hooks';
import { GroupedPortal } from '@highlight-ui/utils-portal-manager';
import { getDateConfigByLocale } from './date-time-config.js';
import styles from './Calendar.module.scss.js';

var basicFlatPickrConfig = function (locale, disabledDates, value, minDate, maxDate, mode, prevArrow, nextArrow) {
  if (disabledDates === void 0) {
    disabledDates = [];
  }

  var _a = getDateConfigByLocale(locale)({
    minDate: minDate,
    maxDate: maxDate
  }),
      flatPickrFormat = _a.flatPickrFormat,
      flatPickrLocale = _a.flatPickrLocale;

  return __assign(__assign(__assign(__assign(__assign({
    defaultDate: value,
    locale: flatPickrLocale,
    disable: disabledDates
  }, minDate ? {
    minDate: minDate
  } : {}), maxDate ? {
    maxDate: maxDate
  } : {}), {
    dateFormat: flatPickrFormat,
    ariaDateFormat: flatPickrFormat,
    animate: false,
    allowInput: true,
    static: true,
    mode: mode,
    monthSelectorType: 'static'
  }), prevArrow ? {
    prevArrow: prevArrow
  } : {}), nextArrow ? {
    nextArrow: nextArrow
  } : {});
};

var Calendar = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var _a;

  var value = props.value,
      onChange = props.onChange,
      isOpened = props.isOpened,
      metadata = props.metadata,
      style = props.style,
      minDate = props.minDate,
      maxDate = props.maxDate,
      _b = props.mode,
      mode = _b === void 0 ? 'single' : _b,
      _c = props.onClickOutside,
      onClickOutside = _c === void 0 ? function () {} : _c,
      disabledDates = props.disabledDates,
      restProps = __rest(props, ["value", "onChange", "isOpened", "metadata", "style", "minDate", "maxDate", "mode", "onClickOutside", "disabledDates"]);

  var locale = useLocale().locale;
  var flatpickrMountPoint = useRef(null);
  var flatpickrInstanceRef = useRef(null);
  var setElement = useClickOutside(function (e) {
    onClickOutside(e.target);
  });
  useEffect(function () {
    if (flatpickrMountPoint.current) {
      var config = basicFlatPickrConfig(locale, disabledDates, value || undefined, minDate, maxDate, mode, "<i class=\"far fa-arrow-left " + styles.switchMonthArrow + "\"/>", "<i class=\"far fa-arrow-right " + styles.switchMonthArrow + "\"/>");
      flatpickrInstanceRef.current = flatpickr(flatpickrMountPoint.current, __assign(__assign({}, config), {
        appendTo: flatpickrMountPoint.current,
        onChange: onChange
      }));
    }

    return function () {
      if (flatpickrInstanceRef.current) {
        flatpickrInstanceRef.current.destroy();
      }

      flatpickrInstanceRef.current = null;
    };
  }, [value, mode, disabledDates, locale, maxDate, minDate, onChange]);
  return /*#__PURE__*/React.createElement(GroupedPortal, null, /*#__PURE__*/React.createElement("div", __assign({
    ref: ref,
    style: style
  }, restProps), /*#__PURE__*/React.createElement("div", __assign({
    ref: setElement,
    className: classnames(styles.calendar, (_a = {}, _a[styles.calendarClosed] = !isOpened, _a[styles.calendarOpened] = isOpened, _a))
  }, metadata ? parseMetadata({
    testId: "calendar-" + metadata.testId
  }) : {}), /*#__PURE__*/React.createElement("div", {
    ref: flatpickrMountPoint
  }))));
});
export { Calendar as default };
//# sourceMappingURL=Calendar.js.map
