import { __rest, __assign } from './../../external/tslib/tslib.es6.js';
import React, { useState, useRef, useMemo, useCallback, useEffect } from 'react';
import { useForkRef } from '@highlight-ui/utils-hooks';
import { forkHandlers } from '@highlight-ui/utils-commons';
import { Select } from '@highlight-ui/select';
import { useLocale } from '@highlight-ui/i18n';
import formatTime from './fn/formatTime.js';
import TimeInput from './TimeInput.js';
import { getTimeConfigByLocale } from './date-time-config.js';
import styles from './ControlledTimePicker.module.scss.js';
import autoCompleteTimeText from './fn/autocompleteTimeText.js';
import getTimeStringFromDate from './fn/getTimeStringFromDate.js';
import createSelectOptionFromDate from './fn/createSelectOptionFromDate.js';
import getDateFromTimeString from './fn/getDateFromTimeString.js';
var defaultDay = new Date();
var defaultPresetTime = [];

var ControlledTimePicker = function (_a, propRef) {
  var className = _a.className,
      _b = _a.day,
      day = _b === void 0 ? defaultDay : _b,
      metadata = _a.metadata,
      onChange = _a.onChange,
      onBlur = _a.onBlur,
      _c = _a.presetTimes,
      presetTimes = _c === void 0 ? defaultPresetTime : _c,
      value = _a.value,
      restProps = __rest(_a, ["className", "day", "metadata", "onChange", "onBlur", "presetTimes", "value"]);

  var locale = useLocale().locale;
  var timeConfig = React.useMemo(function () {
    return getTimeConfigByLocale(locale)();
  }, [locale]);

  var _d = useState(getTimeStringFromDate(value, timeConfig.parseFormat)),
      timeText = _d[0],
      setTimeText = _d[1];

  var inputInFocus = useRef(false);
  var timeOptions = useMemo(function () {
    return presetTimes.map(function (date) {
      return createSelectOptionFromDate(date, timeConfig.parseFormat);
    });
  }, [presetTimes, timeConfig.parseFormat]);
  var selectOptions = useMemo(function () {
    return timeOptions.filter(function (preset) {
      return preset.value.includes(timeText);
    });
  }, [timeOptions, timeText]);
  var selectRef = useRef(null);
  var finalSelectRef = useForkRef([propRef, selectRef]);
  var handleSelectTime = useCallback(function (_a) {
    var selectedTime = _a[0];
    var date = getDateFromTimeString(selectedTime.value, timeConfig.parseFormat, day);
    setTimeText(selectedTime.value);
    inputInFocus.current = false;
    if (onChange) onChange(date, selectedTime.value);
  }, [onChange, day, timeConfig.parseFormat]);
  var handleInputChange = useCallback(function (inputValue) {
    if (inputInFocus.current) {
      var date = getDateFromTimeString(inputValue, timeConfig.parseFormat, day);
      setTimeText(inputValue);
      if (onChange) onChange(date, inputValue);
    }
  }, [day, onChange, timeConfig.parseFormat]);
  var handleInputBlur = useCallback(function (setListVisibility, e) {
    var _a;

    var isClickedOutside = !((_a = selectRef.current) === null || _a === void 0 ? void 0 : _a.contains(e.relatedTarget));

    if (isClickedOutside) {
      var completeValue = formatTime(autoCompleteTimeText(timeText));
      setTimeText(completeValue);
      var newDate = getDateFromTimeString(completeValue, timeConfig.parseFormat, day);

      if (completeValue !== timeText && onChange) {
        onChange(newDate, completeValue);
      }

      setListVisibility(false);
      inputInFocus.current = false;
    }
  }, [timeText, timeConfig.parseFormat, day, onChange]);
  var handleInputFocus = useCallback(function () {
    inputInFocus.current = true;
  }, []);
  useEffect(function () {
    if (!inputInFocus.current) {
      setTimeText(getTimeStringFromDate(value, timeConfig.parseFormat));
    }
  }, [value, timeConfig.parseFormat]);
  return /*#__PURE__*/React.createElement(Select, {
    ref: finalSelectRef,
    className: styles.presetSelect,
    closeOnSelect: true,
    metadata: __assign({}, metadata ? {
      testId: "timeSelect-" + metadata.testId,
      actionName: "timeSelect-" + metadata.actionName
    } : undefined),
    options: selectOptions,
    onSelect: handleSelectTime,
    renderEmptyState: function () {
      return null;
    },
    renderTrigger: function (_a) {
      var onClick = _a.onClick,
          triggerRef = _a.ref,
          setListVisibility = _a.setListVisibility;
      return /*#__PURE__*/React.createElement(TimeInput, __assign({}, restProps, {
        className: className,
        metadata: metadata,
        onBlur: forkHandlers([function (e) {
          return handleInputBlur(setListVisibility, e);
        }, onBlur]),
        onFocus: handleInputFocus,
        onChange: handleInputChange,
        onClick: onClick,
        iconName: timeConfig.iconName,
        value: timeText,
        maskOptions: timeConfig.maskOptions,
        placeholder: timeConfig.placeholder,
        ref: triggerRef
      }));
    },
    searchable: false,
    selectedOptions: []
  });
};

var TimePickerWithRef = /*#__PURE__*/React.forwardRef(ControlledTimePicker);
export { TimePickerWithRef as default };
//# sourceMappingURL=ControlledTimePicker.js.map
