import { __rest, __assign } from './../../external/tslib/tslib.es6.js';
import { Icon } from '@highlight-ui/icon';
import { Input } from '@highlight-ui/input';
import { useLocale } from '@highlight-ui/i18n';
import { parseMetadata, forkHandlers } from '@highlight-ui/utils-commons';
import format from './../../external/date-fns/esm/format/index.js';
import isValid from './../../external/date-fns/esm/isValid/index.js';
import parse from './../../external/date-fns/esm/parse/index.js';
import React, { useState, useEffect, useCallback } from 'react';
import { getTimeConfigByLocale, getDateConfigByLocale } from './date-time-config.js';
import styles from './DateInput.module.scss.js';

function getCompleteValue(value) {
  var timeCanBeAutocompleted = Boolean(value.match(/^\d+:\d$/));
  return timeCanBeAutocompleted ? value + "0" : value;
}

var DateInputWithRef = function (props, ref) {
  var disabled = props.disabled,
      mode = props.mode,
      value = props.value,
      metadata = props.metadata,
      onChange = props.onChange,
      minDate = props.minDate,
      maxDate = props.maxDate,
      _a = props.withIcon,
      withIcon = _a === void 0 ? false : _a,
      disabledDates = props.disabledDates,
      className = props.className,
      restProps = __rest(props, ["disabled", "mode", "value", "metadata", "onChange", "minDate", "maxDate", "withIcon", "disabledDates", "className"]);

  var locale = useLocale().locale;

  var _b = React.useMemo(function () {
    return mode === 'time' ? getTimeConfigByLocale(locale)() : getDateConfigByLocale(locale)({
      minDate: minDate,
      maxDate: maxDate,
      disabledDates: disabledDates
    });
  }, [locale, maxDate, minDate, mode, disabledDates]),
      iconName = _b.iconName,
      maskOptions = _b.maskOptions,
      placeholder = _b.placeholder,
      parseFormat = _b.parseFormat;

  var _c = useState(''),
      dateTimeText = _c[0],
      setDateTimeText = _c[1];

  var _d = useState(false),
      isFocused = _d[0],
      setIsFocused = _d[1];

  useEffect(function () {
    if (value) {
      var parsedNewValue = format(value, parseFormat);
      setDateTimeText(parsedNewValue);
    } else if (value === null) {
      setDateTimeText('');
    }
  }, [parseFormat, value]);

  var getIconColor = function () {
    if (disabled || !isFocused && dateTimeText === '') return 'icon-subdued';
    return 'icon-default';
  };

  var handleOnMaskAccept = useCallback(function (e) {
    setDateTimeText(e.value);
    if (dateTimeText === e.value) return;

    if (onChange) {
      var completeValue = mode === 'time' ? getCompleteValue(e.value) : e.value;
      var parsedInputValue = parse(completeValue, parseFormat, new Date());
      var isValidDateTime = e.value.length === parseFormat.length && isValid(parsedInputValue);
      onChange(isValidDateTime ? parsedInputValue : undefined, completeValue);
    }
  }, [dateTimeText, mode, onChange, parseFormat]);
  return /*#__PURE__*/React.createElement(Input, __assign({
    autoComplete: "off",
    ref: ref,
    disabled: disabled,
    className: className,
    inputClassName: styles.dateTimeInput,
    maskOptions: maskOptions,
    placeholder: placeholder,
    onMaskAccept: handleOnMaskAccept,
    value: dateTimeText,
    fontStyle: "mono"
  }, withIcon ? {
    suffix: /*#__PURE__*/React.createElement(Icon, {
      name: iconName,
      type: "solid",
      color: getIconColor()
    })
  } : {}, parseMetadata(metadata), restProps, {
    onFocus: forkHandlers([function () {
      return setIsFocused(true);
    }, restProps.onFocus]),
    onBlur: forkHandlers([function () {
      return setIsFocused(false);
    }, restProps.onBlur])
  }));
};

var DateInput = /*#__PURE__*/React.forwardRef(DateInputWithRef);
export { DateInput as default };
//# sourceMappingURL=DateInput.js.map
