import { __rest, __assign } from './../../external/tslib/tslib.es6.js';
import React, { useState, useMemo, useCallback } from 'react';
import classnames from 'classnames';
import { parseMetadata, forkHandlers } from '@highlight-ui/utils-commons';
import { Icon } from '@highlight-ui/icon';
import { Input } from '@highlight-ui/input';
import styles from './TimeInput.module.scss.js';

var TimeInputWithRef = function (props, ref) {
  var disabled = props.disabled,
      value = props.value,
      metadata = props.metadata,
      onChange = props.onChange,
      className = props.className,
      onFocus = props.onFocus,
      onBlur = props.onBlur,
      iconName = props.iconName,
      maskOptions = props.maskOptions,
      placeholder = props.placeholder,
      restProps = __rest(props, ["disabled", "value", "metadata", "onChange", "className", "onFocus", "onBlur", "iconName", "maskOptions", "placeholder"]);

  var _a = useState(false),
      isFocused = _a[0],
      setIsFocused = _a[1];

  var icon = useMemo(function () {
    var iconColor = disabled || !isFocused && value === '' ? 'icon-subdued' : 'icon-default';
    return /*#__PURE__*/React.createElement(Icon, {
      name: iconName,
      type: "solid",
      color: iconColor
    });
  }, [disabled, isFocused, iconName, value]);
  var handleOnMaskAccept = useCallback(function (e) {
    if (onChange) {
      onChange(e.value);
    }
  }, [onChange]);
  return /*#__PURE__*/React.createElement(Input, __assign({}, parseMetadata(metadata), restProps, {
    autoComplete: "off",
    ref: ref,
    disabled: disabled,
    inputClassName: classnames(styles.timeInput, className),
    maskOptions: maskOptions,
    placeholder: placeholder,
    onMaskAccept: handleOnMaskAccept,
    value: value,
    suffix: icon,
    onFocus: forkHandlers([function () {
      return setIsFocused(true);
    }, onFocus]),
    onBlur: forkHandlers([function () {
      return setIsFocused(false);
    }, onBlur])
  }));
};

var TimeInput = /*#__PURE__*/React.forwardRef(TimeInputWithRef);
export { TimeInput as default };
//# sourceMappingURL=TimeInput.js.map
